@@ -687,10 +687,11 @@ class VariableClUpdateOtherGitExists(Variable):
     repos_path = 'cl_update_repos_storage'
 
     def get(self):
-        rep = f"{self.Get(self.repos_path)}/container"
-        if os.path.exists(os.path.join(rep, '.git')):
-            return True
-        return False
+        repos = self.Get(self.repos_path)
+        for rep in listDirectory(repos):
+            if not os.path.exists(os.path.join(repos, os.path.join(rep, '.git'))):
+                return False
+        return True
 
 
 
